function [ diagram ] = frame_transform( frame )
% Header
%
% Filename:  frame_transform.m
% Created:   01/08/2015
% Modified:  01/08/2015 "Created"
%            01/22/2015 "Major Update"
%            05/07/2015 "Conversion from aux_transform_frame.m"
%            05/07/2015 "Use of bsxfun addded"
%            07/01/2015 "Name changes"
%
% Author(s): Chae Clark
%            cclark18@math.umd.edu
%            Applied Mathematics & Statistics, and Scientific Computing
%            Department of Mathematics
%            University of Maryland, College Park
%           
% Description:
% This function transforms the frame into a modified version of its diagram
% vectors.
%
% Toolboxes:
% N/A
%
% Input:
% frame   - the frame to be transformed
%
% Output:
% diagram - the transformed graph
%
% Copyright 2015 by Chae A. Clark. All Rights Reserved.
%

% Argument check
if(nargin<1);error('No graph was input!');end

% Set dimensions
[n,m] = size(frame);
d = .5*(n-1)*(n+2);

% Allocate mmemory for sparse matrix
diagram = zeros(m,d);

% Use transpose for efficeint memory management
frame = frame.';

% Store square of elements
sqr = frame.^2;

% Take the difference with the first squares 
diagram(:,1:n-1) = bsxfun(@minus,sqr(:,1),sqr(:,2:end));

% Compute the product of elements
index = n;
for i=1:n-1
    diagram(:,index:index+(n-i-1)) = bsxfun(@times,frame(:,i),frame(:,i+1:n));
    index = index + (n-i);
end

% Transpose returns the correct sizing
diagram = diagram.';
end