function [Phi , normalized_Phi] = generate_frame_Gaussian(N , M , maxIter)
%% Header
%
% Filename:  generate_random_frame.m
% Created:   11/13/2014
% Modified:  11/13/2014 "Created"
%            01/26/2015 "Format Overhaul"
%
% Author(s): Chae Clark
%            cclark18@math.umd.edu
%            Applied Mathematics & Statistics, and Scientific Computing
%            Department of Mathematics
%            University of Maryland, College Park
%
% Description:
% This function generates a random frame Phi of size N-by-M.
%
% Toolboxes:
% n/A
%
% Input:
% N              - the dimension of the frame
%
% M              - the number of frame elements
%
% maxIter        - the maximum number of attempts to create the desired
%                  frame
%
% Output:
% Phi            - the generated frame
%
% normalized_Phi - the generated frame normalized to have elements of unit
%                  l2 norm
%
% Copyright 2015 by Chae A. Clark. All Rights Reserved.
%

%% Preprocessing

if M < N
    error('No Frame Possible!');
end

if nargin < 3
    maxIter = 1E3;
end

if nargin < 2
    M = 3;
end

if nargin < 1
    N = 2;
end

%% Generate Frame

% Generate Normal Gaussian Frame
Phi = randn(N,M);

% Check that a frame has been created
for i=1:maxIter
    [~,I] = rref(Phi);
    
    % If full rank, then return
    if length(I) == N
        Phi = [Phi(:,I) randn(N,M-N)];
        normalized_Phi = Phi ./ repmat(sqrt(sum(Phi.^2,1)) , [N,1]);
        return
    end
    
    % Otherwise, update Phi
    Phi = [Phi(:,I) randn(N,M)];
end
error('Frame Not Created!')

%% Postprocessing

